@@ -28,6 +28,10 @@ else    # 'live' mode
     $INIT_SCRIPTS_DIR/occupy-space.sh
 fi
 
+# restore the lvm config as it was in the
+# initial chroot environment
+restore_lvm_conf
+
 # restore and start the usual init
 rm /sbin/init
 mv /sbin/init.orig /sbin/init
